<?php

namespace App\Http\Controllers\Api;

use Illuminate\Http\Request;
use App\Http\Controllers\Api\ApiBaseController;
use App\Http\Services\EmailService;
use App\Models\Appointment;


class ApiAppointmentController extends ApiBaseController
{
    public $emailService;

    public function __construct(Request $request, EmailService $emailService)
    {
        parent::__construct($request);
        $this->emailService = $emailService;
    }

    public function create(Request $request){
        $data = $this->getFormData($request);
        $response = $this->callJavaApi('/appointment/create', $data);
        if(!@$response['success']){
            return $this->fail($response['message']);
        }

        $appointment = Appointment::where('uid', $response['data'])->first();
        if($appointment){
            $this->emailService->notifyClientOnNewAppointment($appointment);
            $this->emailService->notifyProOnNewAppointment($appointment);
        }
        return $this->pass($response['data']);
    }
    
    public function requestConfirmation(Request $request){
        $data = $this->getFormData($request);
        $response = $this->callJavaApi('/appointment/sendConfirmationRequestViaEmailAndSms', $data);
        if(!@$response['success']){
            return $this->fail($response['message']);
        }
        $appointment = Appointment::where('uid', $data['uid'])->first();
        if($appointment){
            $this->emailService->notifyClientToConfirmAppointment($appointment);
        }
        return $this->pass();
    }
    
}
